@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: qx_imager.cpp,v 1.14 2007/03/25 20:48:24 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: qx_imager.cpp,v 1.15 2008/08/05 20:52:56 bpearlmutter Exp $
+// $Name: release_3_5_21 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -770,9 +770,13 @@ QXImager::QXImager(Display * _displ, void * _visual,
 void
 QXImager::dither(GPixmap & gpix, int x0, int y0)
 {
-   if (is_color)
-      if (depth<15) gpix.ordered_666_dither(x0, y0);
-      else if (depth<24) gpix.ordered_32k_dither(x0, y0);
+  if (is_color)
+    {
+      if (depth<15)
+	gpix.ordered_666_dither(x0, y0);
+      else if (depth<24)
+	gpix.ordered_32k_dither(x0, y0);
+    }
 }
 
 void
