@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: col_db.cpp,v 1.7 2007/03/25 20:48:24 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: col_db.cpp,v 1.8 2008/03/17 12:18:34 leonb Exp $
+// $Name: release_3_5_21 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -86,7 +86,7 @@ ColorDB::ColorItem	ColorDB::color[]=
    { "gray",		211, 211, 211 }
 };
 
-char ** ColorDB::name;
+const char ** ColorDB::name;
 unsigned char * ColorDB::red;
 unsigned char * ColorDB::green;
 unsigned char * ColorDB::blue;
@@ -108,7 +108,7 @@ ColorDB::ColorDB(void)
    red=new unsigned char[colors];
    green=new unsigned char[colors];
    blue=new unsigned char[colors];
-   name=new char*[colors];
+   name=new const char*[colors];
    
    if (!red || !green || !blue || !name)
       G_THROW("ColorDB::ColorDB(): Not enough memory to initialize color database.");
