@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: col_db.h,v 1.8 2007/03/25 20:48:24 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: col_db.h,v 1.9 2008/03/16 14:07:06 leonb Exp $
+// $Name: release_3_5_21 $
 
 #ifndef HDR_COL_DB
 #define HDR_COL_DB
@@ -83,12 +83,12 @@ public:
    class ColorItem
    {
    public:
-      char		* name;
+      const char	* name;
       unsigned char	red, green, blue;
    };
    static ColorItem	color[];
    static int		colors;
-   static char 		** name;
+   static const char	** name;
    static unsigned char	* red, * green, * blue;
    
    static int	GetColorNum(u_int32 color);
