@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: qd_prefs.cpp,v 1.16 2007/03/25 20:48:26 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: qd_prefs.cpp,v 1.17 2008/08/05 20:52:26 bpearlmutter Exp $
+// $Name: release_3_5_21 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -357,13 +357,13 @@ QDLensPrefs::slotHlHotKeyChanged(DjVuPrefs::HLButtType key)
 {
       // Make sure that we don't have the same button selected
    QString cur_text=hkey_menu->currentText();
-   if (key==DjVuPrefs::HLB_CTRL && cur_text==ctrl_hkey ||
-       key==DjVuPrefs::HLB_SHIFT && cur_text==shift_hkey ||
-       key==DjVuPrefs::HLB_ALT && cur_text==alt_hkey)
+   if ((key==DjVuPrefs::HLB_CTRL && cur_text==ctrl_hkey) ||
+       (key==DjVuPrefs::HLB_SHIFT && cur_text==shift_hkey) ||
+       (key==DjVuPrefs::HLB_ALT && cur_text==alt_hkey))
      setComboBoxCurrentItem(hkey_menu, mid_hkey);
 }
-   
-QDLensPrefs::QDLensPrefs(DjVuPrefs * prefs, QWidget * parent, const char * name) 
+
+QDLensPrefs::QDLensPrefs(DjVuPrefs * prefs, QWidget * parent, const char * name)
   : QWidget(parent, name)
 {
    DEBUG_MSG("QDLensPrefs::QDLensPrefs(): Creating 'Magnifying Glass' box...\n");
