@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: qd_print_dialog.cpp,v 1.29 2007/03/25 20:48:26 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: qd_print_dialog.cpp,v 1.31 2008/08/19 12:34:31 bpearlmutter Exp $
+// $Name: release_3_5_21 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -98,6 +98,20 @@
 #include <errno.h>
 #include <signal.h>
 
+// -- MAXPATHLEN
+#ifndef MAXPATHLEN
+# ifdef _MAX_PATH
+#  define MAXPATHLEN _MAX_PATH
+# else
+#  define MAXPATHLEN 1024
+# endif
+#else
+# if ( MAXPATHLEN < 1024 )
+#  undef MAXPATHLEN
+#  define MAXPATHLEN 1024
+# endif
+#endif
+
 /** Avoid name clashes on solaris! */
 #ifdef PS
 # undef PS
@@ -525,12 +539,14 @@ QDPrintDialog::done(int rc)
 
          int  bookletMode=(int)DjVuToPS::Options::OFF;
          if (bk_mode_butt->isChecked())
-           if (! strcmp(bk_mode_menu->currentText(), tr(recto_verso_str)))
-             bookletMode=(int)DjVuToPS::Options::RECTOVERSO;
-           else if (! strcmp(bk_mode_menu->currentText(), tr(recto_only_str)))
-             bookletMode=(int)DjVuToPS::Options::RECTO;
-           else if (! strcmp(bk_mode_menu->currentText(), tr(verso_only_str)))
-             bookletMode=(int)DjVuToPS::Options::VERSO;
+	   {
+	     if (! strcmp(bk_mode_menu->currentText(), tr(recto_verso_str)))
+	       bookletMode=(int)DjVuToPS::Options::RECTOVERSO;
+	     else if (! strcmp(bk_mode_menu->currentText(), tr(recto_only_str)))
+	       bookletMode=(int)DjVuToPS::Options::RECTO;
+	     else if (! strcmp(bk_mode_menu->currentText(), tr(verso_only_str)))
+	       bookletMode=(int)DjVuToPS::Options::VERSO;
+	   }
          int  bookletMax=4 * bk_max_spin->value();
          int  bookletAlign=bk_align_spin->value();
          int  bookletFold=bk_fold_spin->value();
