@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: qd_search_dialog.cpp,v 1.14 2007/03/25 20:48:26 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: qd_search_dialog.cpp,v 1.15 2008/08/05 20:52:26 bpearlmutter Exp $
+// $Name: release_3_5_21 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -246,8 +246,8 @@ QDSearchDialog::slotSearch(void)
 	    // Didn't find anything. Switch to the next page or give up
 	 int pages_num=doc->get_pages_num();
 	 if (!all_pages_butt->isChecked() ||
-	     fwd && page_num>=pages_num-1 ||
-	     !fwd && page_num==0)
+	     (fwd && page_num>=pages_num-1) ||
+	     (!fwd && page_num==0))
 	 {
 	    if (asked_once)
 	    {
