@@ -1026,10 +1026,6 @@ automatic color matching.</source>
         <source>&amp;Stop</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Loading page </source>
-        <translation type="obsolete"></translation>
-    </message>
     <message>
         <source>End of document reached. Continue from the beginning?</source>
         <translation type="unfinished"></translation>
