@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuDocument.cpp,v 1.18 2007/11/26 14:48:34 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: DjVuDocument.cpp,v 1.21 2008/08/05 20:50:35 bpearlmutter Exp $
+// $Name: release_3_5_21 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -665,13 +665,15 @@ DjVuDocument::check_unnamed_files(void)
 int
 DjVuDocument::get_pages_num(void) const
 {
-   check();
-   if (flags & DOC_TYPE_KNOWN)
+  check();
+  if (flags & DOC_TYPE_KNOWN)
+    {
       if (doc_type==BUNDLED || doc_type==INDIRECT)
-	 return djvm_dir->get_pages_num();
+	return djvm_dir->get_pages_num();
       else if (flags & DOC_NDIR_KNOWN)
-	 return ndir->get_pages_num();
-   return 1;
+	return ndir->get_pages_num();
+    }
+  return 1;
 }
 
 GURL
@@ -689,6 +691,8 @@ DjVuDocument::page_to_url(int page_num) const
          {
            if (page_num<1) 
              url=init_url;
+           else
+             G_THROW( ERR_MSG("DjVuDocument.big_num") );
            break;
          }
 	 case OLD_INDEXED:
@@ -1797,7 +1801,7 @@ DjVuDocument::expand(const GURL &codebase, const GUTF8String &idx_name)
 }
 
 void
-DjVuDocument::save_as(const GURL &where, const bool bundled)
+DjVuDocument::save_as(const GURL &where, bool bundled)
 {
    DEBUG_MSG("DjVuDocument::save_as(): where='" << where <<
 	     "', bundled=" << bundled << "\n");
