@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GURL.cpp,v 1.27 2007/11/26 15:11:05 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: GURL.cpp,v 1.29 2008/01/27 16:16:26 leonb Exp $
+// $Name: release_3_5_21 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -85,9 +85,6 @@
 # include <tchar.h>
 # include <windows.h>
 # include <direct.h>
-# ifndef __MINGW32__
-#  include <atlbase.h>
-# endif
 #endif /* WIN32 */
 
 // -- MAXPATHLEN
@@ -1418,14 +1415,7 @@ GURL::is_file(void) const
     DWORD dwAttrib;
     dwAttrib = GetFileAttributesW(wfilename);
     if((dwAttrib|1) == 0xFFFFFFFF)
-      {
-#ifdef __MINGW32__
         dwAttrib = GetFileAttributesA(NativeFilename());
-#else
-        USES_CONVERSION ;
-        dwAttrib = GetFileAttributes(A2CT(NativeFilename())) ;//MBCS cvt
-#endif
-      }
     retval=!( dwAttrib & FILE_ATTRIBUTE_DIRECTORY );
 #else
 # error "Define something here for your operating system"
@@ -1459,14 +1449,7 @@ GURL::is_local_path(void) const
     DWORD dwAttrib;
     dwAttrib = GetFileAttributesW(wfilename);
     if((dwAttrib|1) == 0xFFFFFFFF)
-      {
-#ifdef __MINGW32__
         dwAttrib = GetFileAttributesA(NativeFilename());
-#else
-        USES_CONVERSION ;
-        dwAttrib = GetFileAttributes(A2CT(NativeFilename())) ;//MBCS cvt
-#endif
-      }
     retval=( (dwAttrib|1) != 0xFFFFFFFF);
 #endif
   }
@@ -1504,14 +1487,7 @@ GURL::is_dir(void) const
     DWORD dwAttrib;
     dwAttrib = GetFileAttributesW(wfilename);
     if((dwAttrib|1) == 0xFFFFFFFF)
-      {
-#ifdef __MINGW32__
         dwAttrib = GetFileAttributesA(NativeFilename());
-#else
-        USES_CONVERSION ;
-        dwAttrib = GetFileAttributes(A2CT(NativeFilename())) ;//MBCS cvt
-#endif
-      }
     retval=((dwAttrib != 0xFFFFFFFF)&&( dwAttrib & FILE_ATTRIBUTE_DIRECTORY ));
 #else
 # error "Define something here for your operating system"
@@ -1560,18 +1536,10 @@ GURL::mkdir() const
       else 
         retval = ::mkdir(NativeFilename(), 0755);
 #elif defined(WIN32)
-# ifdef __MINGW32__
       if (is_dir())
         retval = 0;
       else 
         retval = CreateDirectoryA(NativeFilename(), NULL);
-# else
-      USES_CONVERSION;
-      if (is_dir())
-        retval = 0;
-      else 
-        retval = CreateDirectory(A2CT(NativeFilename()), NULL);
-# endif
 #else
 # error "Define something here for your operating system"
 #endif
@@ -1594,18 +1562,10 @@ GURL::deletefile(void) const
       else
         retval = ::unlink(NativeFilename());
 #elif defined(WIN32)
-# ifdef __MINGW32__
       if (is_dir())
         retval = ::RemoveDirectoryA(NativeFilename());
       else
         retval = ::DeleteFile(NativeFilename());
-# else
-      USES_CONVERSION;
-      if (is_dir())
-        retval = ::RemoveDirectory(A2CT(NativeFilename()));
-      else
-        retval = ::DeleteFile(A2CT(NativeFilename()));
-# endif
 #else
 # error "Define something here for your operating system"
 #endif
@@ -1857,18 +1817,19 @@ GURL::expand_name(const GUTF8String &xfname, const char *from)
       }
     }
     // Process path components
-    for(;*fname== slash || *fname==backslash;fname++)
-      EMPTY_LOOP;
     while(*fname)
     {
+      for(;*fname== slash || *fname==backslash;fname++)
+        EMPTY_LOOP;
       if (fname[0]== dot )
       {
         if (fname[1]== slash || fname[1]==backslash || !fname[1])
         {
           fname++;
           continue;
-        }else if ((fname[1] == dot)
-          && (fname[2]== slash || fname[2]==backslash || !fname[2]))
+        }
+		else if ((fname[1] == dot)
+                 && (fname[2]== slash || fname[2]==backslash || !fname[2]))
         {
           fname += 2;
           char *back=_tcsrchr(string_buffer,backslash);
@@ -1883,99 +1844,21 @@ GURL::expand_name(const GUTF8String &xfname, const char *from)
           s = string_buffer;
           continue;
         }
-        char* s2=s;//MBCS DBCS
-        for(;*s;s++) 
-          EMPTY_LOOP;
-        char* back = _tcsrchr(s2,backslash);//MBCS DBCS
-        if ((s>string_buffer)&&(*(s-1)!= slash)&&
-            (back == NULL || (back!=NULL && s-1 != back) ))//MBCS DBCS
-        {
-          *s = backslash;
-          s++;
-        }
-        while (*fname && *fname!= slash && *fname!=backslash)
-        {
-          *s = *fname++;
-          if ((size_t)((++s)-string_buffer) > maxlen)
-            G_THROW( ERR_MSG("GURL.big_name") );
-        }
-        *s = 0;
       }
       char* s2=s;//MBCS DBCS
       for(;*s;s++) 
         EMPTY_LOOP;
-      char* back = _tcsrchr(s2,backslash);//MBCS DBCS
-      if ((s>string_buffer)&&(*(s-1)!= slash)
-          &&(back == NULL || (back!=NULL && s-1 != back) ))//MBCS DBCS
-      {
-        *s = backslash;
-        s++;
-      }
+	  if (s > string_buffer && s[-1] != slash && s[-1] != backslash)
+        *s++ = backslash;
       while (*fname && (*fname!= slash) && (*fname!=backslash))
       {
-        *s = *fname++;
-        if ((size_t)((++s)-string_buffer) > maxlen)
+        if (s > string_buffer + maxlen)
           G_THROW( ERR_MSG("GURL.big_name") );
+        *s++ = *fname++;
       }
       *s = 0;
-      for(;(*fname== slash)||(*fname==backslash);fname++)
-        EMPTY_LOOP;
     }
   }
-#elif defined(macintosh) // MACINTOSH implementation
-  strcpy(string_buffer, (const char *)(from?from:GOS::cwd()));
-  
-  if (!GStringRep::cmp(fname, string_buffer,strlen(string_buffer)) || is_file(fname))
-  {
-    strcpy(string_buffer, "");//please don't expand, the logic of filename is chaos.
-  }
-  
-  // Process path components
-  char *s = string_buffer + strlen(string_buffer);
-  if(fname)
-  {
-    for(;fname[0]==colon;fname++)
-      EMPTY_LOOP;
-    while(fname[0])
-    {
-      if (fname[0]== dot )
-      {
-        if (fname[1]==colon || !fname[1])
-        {
-          fname++;
-          continue;
-        }
-        if ((fname[1]== dot )
-          &&(fname[2]==colon || fname[2]==0))
-        {
-          fname +=2;
-          for(;(s>string_buffer+1)&&(*(s-1)==colon);s--)
-            EMPTY_LOOP;
-          for(;(s>string_buffer+1)&&(*(s-1)!=colon);s--)
-            EMPTY_LOOP;
-          continue;
-        }
-      }
-      if ((s==string_buffer)||(*(s-1)!=colon))
-      {
-        *s = colon;
-        s++;
-      }
-      while (*fname!=0 && *fname!=colon)
-      {
-        *s = *fname++;
-        if ((++s)-string_buffer > maxlen)
-          G_THROW( ERR_MSG("GURL.big_name") );
-      }
-      *s = 0;
-      for(;fname[0]==colon;fname++)
-        EMPTY_LOOP;
-    }
-  }
-  for(;(s>string_buffer+1) && (*(s-1)==colon);s--)
-    EMPTY_LOOP;
-  *s = 0;
-  return ((string_buffer[0]==colon)?(string_buffer+1):string_buffer);
 #else
 # error "Define something here for your operating system"
 #endif  
