@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 //
-// $Id: djvused.cpp,v 1.30 2007/12/02 04:14:45 leonb Exp $
-// $Name: release_3_5_20_2 $
+// $Id: djvused.cpp,v 1.34 2008/08/05 20:48:20 bpearlmutter Exp $
+// $Name: release_3_5_21 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -1762,7 +1762,7 @@ command_save(void)
   if (!g().doc->can_be_saved())
     verror("cannot save old format (use save-bundled or save-indirect)");
   if (nosave)
-    vprint("save-indirect: not saving anything (-n was specified)");
+    vprint("save: not saving anything (-n was specified)");
   else if (!modified)
     vprint("save: document was not modified");
   else 
@@ -1998,11 +1998,13 @@ main(int argc, char **argv)
       // Execute
       execute();
       if (modified)
-        if (save)
-          command_save();
-        else
-          fprintf(stderr,"djvused: (warning) file was modified but not saved\n");
-    }
+	{
+	  if (save)
+	    command_save();
+	  else
+	    fprintf(stderr,"djvused: (warning) file was modified but not saved\n");
+	}
+     }
   G_CATCH(ex)
     {
       ex.perror();
